#
# spec file for package golang-github-linuxdeepin-go-lib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define   _name           go-lib
%define   import_path     github.com/linuxdeepin/go-lib

Name:           golang-github-linuxdeepin-go-lib
Version:        6.0.0
Release:        1.10
Summary:        Go bindings for Deepin Desktop Environment development
License:        GPL-3.0-or-later
Group:          Development/Languages/Golang
URL:            https://github.com/linuxdeepin/go-lib
Source0:        https://github.com/linuxdeepin/go-lib/archive/%{version}/%{_name}-%{version}.tar.gz
# The development package of golang is named *-source, please skip this rpmlint elibX11-1rror.
Source1:        golang-github-linuxdeepin-go-lib-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  golang-packaging
BuildRequires:  libpulse0
BuildRequires:  mobile-broadband-provider-info
BuildRequires:  golang(github.com/linuxdeepin/go-gir/gio-2.0)
BuildRequires:  golang(github.com/linuxdeepin/go-gir/glib-2.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(x11)
BuildArch:      noarch
Requires:       golang(github.com/linuxdeepin/go-gir/gio-2.0)
Requires:       golang(github.com/linuxdeepin/go-gir/glib-2.0)
AutoReq:        Off
%{go_provides}

%description
DLib is a set of Go bindings/libraries for DDE development.
Containing dbus (forking from guelfey), glib, gdkpixbuf, pulse and more.

%prep
%setup -q -n %{_name}-%{version}

%build
export GO111MODULE=off
%goprep %{import_path}

%install
%goinstall
%gosrc
install -m 0644 %{_builddir}/go/src/%{import_path}/gdkpixbuf/blur.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/gdkpixbuf/
install -m 0644 %{_builddir}/go/src/%{import_path}/gdkpixbuf/gaussianiir2d.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/gdkpixbuf/
install -m 0644 %{_builddir}/go/src/%{import_path}/gdkpixbuf/gdk_pixbuf_utils.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/gdkpixbuf/
install -m 0644 %{_builddir}/go/src/%{import_path}/pulse/dde-pulse.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/pulse/
install -m 0644 %{_builddir}/go/src/%{import_path}/pulse/meter.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/pulse/
install -m 0644 %{_builddir}/go/src/%{import_path}/sound/player.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/sound/
install -m 0644 %{_builddir}/go/src/%{import_path}/stb_vorbis/stb_vorbis.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/stb_vorbis/
install -m 0644 %{_builddir}/go/src/%{import_path}/pam/transaction.c \
                %{buildroot}%{go_contribsrcdir}/%{import_path}/pam/
%gofilelist

%fdupes %{buildroot}

%files -f file.lst
%defattr(-,root,root)
%doc README.md
%license LICENSE

%changelog
* Sat Apr  2 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.0.0
  * Change pkg.deepin.io to github.com
  * Fix bugs
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- Use last stable version of go to build
* Fri Feb 18 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.4
  * Add SyncWriteFile
  * Add BindTextdomainCodeset
  * Fix bugs
* Fri Jan 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Keep golang version on 1.15 on Leap15.4+
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.35
  * Fix bugs
* Wed Oct 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Leap 15.4+
* Sun Oct 24 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.15
  * Add SyncWriteFile
  * Add BindTextdomainCodeset
  * Fix Mock
* Fri Jul 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.10
  * Fix proxy environment variable
  * Add mock support
  * Fix DBus test
  * Update test modules
* Fri May 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Keep golang version on 1.15 on Tumbleweed, the project does not support
  golang 1.16+
* Wed Mar 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.0
  * Update APIs
  * Fix bugs
* Thu Apr 25 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.10.2
  * chore(desktopappinfo): remove redundant println
  * fix: build failed
  * feat(desktopappinfo): do not process X-Deepin-Vendor field
* Wed Apr 10 2019 Hillwood Yang <hillwood@opensuse.org>
- Add c language files.
* Sun Mar 17 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.10.0
  * Fix(asound): SelemHasCaptureSwitchJoined wrong
  * Change(api): asound add more functions
  * fix(dbusutil): proxy.Object removeHandler not work if ruleAuto is false
* Mon Mar 11 2019 hillwood@opensuse.org
- Clean up spec
* Wed Mar  6 2019 Aaron Stern <ukbeast89@ptotonmail.com>
- Update version to 1.9.2
  * chore(dbusutil): RemoveHandler check signal ext
  * chore: use pkg.deepin.io/gir
  * fix(proxy): abnormally clear env vars when modifying config
  * refactor: fix a typo
  * change(api): appinfo AppLaunchContext add method SetCmdSuffixes
  * fix(desktpappinfo): failed to parse Exec field of wine programs desktop files
  * chore: use dh golang build system on `sw_64`
  * feat(dbusutil): gsprop.Enum add methods GetString and SetString
  * chore(`sound_effect`): player add method Finder
  * fix(dbus1): defaultSignalHandler.DeliverSignal
  * chore(dbus1): skip test transport nonce tcp
  * chore(dbus1): update to the latest upstream code
  * feat(imgutil): add method CanDecodeConfig
  * feat: add lib imgutil
  * feat(desktopappinfo): support key X-Deepin-Vendor
  * fix(dbusutil): gsprop nil pointer panic
  * feat: add lib shell
  * chore(gettext): do not run test
  * fix: make install lost a file
  * chore: add makefile for `sw_64`
  * feat(sound-effect): check theme and event validity
  * chore(gettext): do not run test
  * fix(desktopappinfo): expandFieldCode
  * chore(proxy): defer proxySettings init
  * fix: test failed
  * chore(dbusutil): gsprop add mutex prevent data race
  * chore(dbusutil): request name error include name
  * chore: remove polkit
  * chore(gdkpixbuf): use go-x11-client
  * fix: play wav file with pulseaudio get error
  * chore(debian): update debian control
  * chore(appinfo): use go-x11-client
  * feat(audio): improve event handling
  * fix(pulse): no subscribe server event
  * fix(pulse): Context data race
  * fix(pulse): event error should handle in  go space
  * perf(pulse): avoid wasting CPU time to poll connect state
  * feat(dbusutil): dbusutil-gen add do not edit header
  * fix(pam): cbPAMConv return two values
  * fix(desktopappinfo): incorrect use of os.Chdir to set working directory of cmd
  * fix(sound_effect): fix alsa backend play failed
  * chore(debian): add dependency on libpam0g-dev
  * feat(pam): add lib pam
  * Merge "feat(dbusutil): proxy.Object can choose not to use auto rule"
  * feat(dbusutil): proxy.Object can choose not to use auto rule
  * fix(pulse): protect pa_stream
  * fix(pulse): protect sink_suspend and meter
  * fix(pulse): protect pa_context_unref
  * feat(dbusutil): add support for auto generate code
  * chore: update license
  * `sound_effect`: fix alsa play backend HWParams wrong
  * `sound_effect`: fix can not compile with go 1.4
* Fri Mar 23 2018 hillwood@opensuse.org
- Update version to 3.1.26
  * perf: unref the `pa_operation` in macro "DEFINE"
  * feat: dbusutil/gsprop add Uint64 type
  * fix(pulse): data race on pulse.Context.free
  * refactor(pulse): hold lock when starting mainloop
  * feat(dbusutil): new api
  * refactor(pulse): remove global variable of `pa_threaded_mainloop`
  * refactor(pulse): hide internal functions
  * feat(dbusutil): hide log output
  * feat(dbusutil): allow field type pointer implements the Property interface
  * feat(dbusutil): delay emit property changed
  * doc: add document about dbusutil
  * feat(dbusutil): improves object introspection
  * fix(dbusutil): PropsMaster Begin and End
  * fix(dbusutil): no check impl is nil
  * feat(dbusutil): add PropsMaster
  * fix(dbusutil): method RequestName panic
  * feat(dbusutil) add method NameHasOwenr and GetNameOwner
  * fix(dbusutil/gsprop): use path property to connect changed
  * fix(dbusutil): auto quit
  * fix(dbusutil): ToError panic if param err is nil
  * feat: add lib dbusutil
  * fix(encoding/kv): constants value wrong
  * refactor: reduce global `success_cb` variable
  * fix: protect global variable "sourceMeterCBs"
  * chore: update license
  * feat: lib dbus/property and proxy use new lib gsettings
  * feat: add lib gsettings
  * fix(dbus1): test SystemBus failed in build env
  * add lib dbus1
* Thu Mar  1 2018 hillwood@opensuse.org
- Update version to 1.2.4
  * fix Adapt lintian
  * asound: add more types and functions
  * sound_effect: fix alsa play backend HWParams wrong
  * notify: fix notification Update and Show
  * sound_effect: fix can not compile with go 1.4
  * dbus: fix SetAutoDestroyHandler
  * add lib cgroup
  * pulse/simple: fix wrong error handling
  * appinfo: do not call GetStartupNotifyId if timestamp is 0
  * add some audio libs
  * fix package golang-dlib-dev depends wrong
  * fix: race condition on HasNewMessage
  * asound: add method SetRateNear and GetDeviceNameHints
* Tue Nov 28 2017 hillwood@opensuse.org
- Update to 1.2.2
  * Fix concurrent access dbus PropertyProxy
  * Add StartCommand method for DestkopAppInfo and DesktopAction
  * Add field Section for DesktopAction
  * Add SetDataDirs in desktopappinfo
* Wed Nov  8 2017 hillwood@opensuse.org
- Add Group tag.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
